import es
import random
import gamethread
import playerlib

import wcs
from wcs import wcs

name = 'Michelangelo'
race = wcs.Race(name)

race.registerAuthor('Wolf')

text = race.loadStrings()

######################################
config = race.config()

config.addComment('********************')
config.addComment('Turtle Training')
config.addComment('  Gain more health, speed, high jump and a chance to evade when hit')
config.addComment('********************')
config.addComment()
trainingMaxLevel      = config.addVar('trainingMaxLevel',     10, 'Max level')
trainingLevelInterval = config.addVar('trainingLevelInterval', 2, 'Level interval')
trainingHealth        = config.addVar('trainingHealth',       10, '10 health per level')
trainingSpeed         = config.addVar('trainingSpeed',         3, '.02 speed per level')
trainingJump          = config.addVar('trainingJump',          6, '1 - level * 6 * .01')
trainEvadePercent     = config.addVar('trainEvadePercent',     4, '4 * level')

config.addComment()
config.addComment('********************')
config.addComment('Weapon Training')
config.addComment('  Do extra damage')
config.addComment('********************')
config.addComment()
weaponMaxLevel      = config.addVar('weaponMaxLevel',     10, 'Max level')
weaponLevelInterval = config.addVar('weaponLevelInterval', 3, 'Level interval')
weaponDamage        = config.addVar('weaponDamage',        5, 'Extra damage') 

config.addComment()
config.addComment('********************')
config.addComment('Hard Shell')
config.addComment('  Gain more armor')
config.addComment('********************')
config.addComment()
shellMaxLevel      = config.addVar('shellMaxLevel',     10, 'Max level')
shellLevelInterval = config.addVar('shellLevelInterval', 2, 'Level interval')
shellArmor         = config.addVar('shellArmor',       100, '100 armor per level')

config.addComment()
config.addComment('********************')
config.addComment('Play Time')
config.addComment('  +Ultimate Puts glue on the floor to freeze nearby enemies') 
config.addComment('********************')
config.addComment()
playMaxLevel      = config.addVar('playMaxLevel',      5, 'Max level')
playMinLevel      = config.addVar('playMinLevel',     30, 'Min level')
playLevelInterval = config.addVar('playLevelInterval', 5, 'Level interval')
playCoolDown      = config.addVar('playCoolDown',      6, 'Cool down time')
playTime          = config.addVar('playTime',          3, 'Time frozen')
playDistance      = config.addVar('playDistance',     50, 'Distance')

config.load(True)
########################################
wcs.Race(name).registerSkill("Turtle Training", int(trainingMaxLevel), int(trainingLevelInterval), "You gain more health, speed and higher jump as well as a chance to evade attacks.")
wcs.Race(name).registerSkill("Weapon Training", int(weaponMaxLevel), int(weaponLevelInterval), "You learn to master your weapon.")
wcs.Race(name).registerSkill("Hard Shell", int(trainingMaxLevel), int(trainingLevelInterval), "Your hard shell will protect you from most attacks.")
wcs.Race(name).registerUltimate("Play Time", int(playMinLevel), int(playMaxLevel), int(playLevelInterval), "You love to have fun so you glue nearby enemies to the floor. <+Ultimate>") 
########################################

def player_spawn(ev):
    userid = ev['userid']
    player = wcs.Command(userid)
    
    if wcs.GetRace(userid) == name:
        playerlib.getPlayer(userid).set('model', 'models/player/techknow/tmnt/michelangelo.mdl')
        
        es.server.cmd('est_RemoveWeapon %s %s'%(userid, 1))
        es.server.cmd('est_RemoveWeapon %s %s'%(userid, 2))	

    turtleTrainingLevel = wcs.GetLevel(userid, name, 'Turtle Training')
    if turtleTrainingLevel:

        speed  = turtleTrainingLevel * int(trainingSpeed) * .01
        health = turtleTrainingLevel * int(trainingHealth)
        jump   = 1 - turtleTrainingLevel * int(trainingJump) * .01
            
        player.SpeedAdd(speed)
        player.HealthAdd(health)
            
        es.tell(userid, '#multi', text('training', {'speed': speed * 100, 'jump': jump * 100, 'health': health}, playerlib.getPlayer(userid).get("lang") ) )
            
        armorLevel = wcs.GetLevel(userid, name, 'Hard Shell')
        if armorLevel:
            armor = armorLevel * int(shellArmor)
            
            player.Armor(armor)
            
            es.tell(userid, '#multi', text('shell', {'armor': armor}, playerlib.getPlayer(userid).get("lang") ) )
def player_jump(ev):
    userid = ev['userid']
    player = wcs.Command(userid)
    turtleTrainingLevel = wcs.GetLevel(userid, name, 'Turtle Training')
    if turtleTrainingLevel:
        jump   = 1 - turtleTrainingLevel * int(trainingJump) * .01
        player.SetGravity(jump)

  
def item_pickup(ev):
    userid = ev['userid']
    
    if wcs.GetRace(userid) == name:
        es.server.cmd('est_RemoveWeapon %s %s'%(userid, 1))
        es.server.cmd('est_RemoveWeapon %s %s'%(userid, 2))

def player_hurt(ev):
    userid   = ev['userid']
    attacker = ev['attacker']
    damage   = int(ev['dmg_health'])
    victim   = wcs.Command(userid)
    
    weaponLevel = wcs.GetLevel(attacker, name, 'Weapon Training') * (int(weaponDamage) * .01)
    if ev['weapon'] == "knife" and weaponLevel:
        victim.Damage(damage * weaponLevel, 32, attacker)
        es.tell(attacker, '#multi', text('weapon attacker', {'damage' : damage * weaponLevel, 'player': es.getplayername(userid)}, playerlib.getPlayer(attacker).get("lang") ) )
        es.tell(userid, '#multi', text('weapon victim', {'damage' : damage * weaponLevel, 'player': es.getplayername(attacker)}, playerlib.getPlayer(attacker).get("lang") ) )

def prep_hurt(ev):
    userid   = ev['userid']
    attacker = ev['attacker']
    damage   = int(ev['dmg_health'])
    victim   = wcs.Command(userid)
    
    if attacker:
        evadeLevel = wcs.GetLevel(userid, name, 'Turtle Training') * int(trainEvadePercent)
        if evadeLevel:
            if evadeLevel >= random.randint(1,100):
                victim.SaveLife(damage)
                es.tell(userid, '#multi', text('evade', {'damage' : damage}, playerlib.getPlayer(userid).get("lang") ) )

def player_ultimate_on(ev):
    userid = ev['userid']
    team   = es.getplayerteam(userid)
    
    if team == 2:
        filter = '#ct'
    elif team == 3:
        filter = '#t'
        
    playLevel = wcs.GetLevel(userid, name, 'Play Time')
    distance  = playLevel * playDistance
    coolDown  = 60 - int(playCoolDown * playLevel)
    
    if playLevel:
        if not wcs.Command(userid).GetCoolDown('Play Time'):
            es.tell(userid, '#multi', text('glue', playerlib.getPlayer(userid).get("lang") ) )
            wcs.Command(userid).Near(distance, Glue, filter)
            wcs.Command(userid).SetCoolDown('Play Time', coolDown)

def Glue(userid, attacker):
    playLevel = wcs.GetLevel(attacker, name, 'Play Time')
    time      = playLevel * int(playTime) *.1
    wcs.Command(userid).Freeze(time)
    es.tell(userid, '#multi', text('glued', playerlib.getPlayer(userid).get("lang") ) )