import es
import random
import gamethread
import playerlib

import wcs
from wcs import wcs

name = 'Raphael'
race = wcs.Race(name)

race.registerAuthor('Wolf')

text = race.loadStrings()

######################################
config = race.config()

config.addComment('********************')
config.addComment('Turtle Training')
config.addComment('  Gain more health, speed, high jump and a chance to evade when hit')
config.addComment('********************')
config.addComment()
trainingMaxLevel      = config.addVar('trainingMaxLevel',     10, 'Max level')
trainingLevelInterval = config.addVar('trainingLevelInterval', 2, 'Level interval')
trainingHealth        = config.addVar('trainingHealth',       10, '10 health per level')
trainingSpeed         = config.addVar('trainingSpeed',         3, '.03 speed per level')
trainingJump          = config.addVar('trainingJump',          6, '1 - level * 6 * .01')
trainEvadePercent     = config.addVar('trainEvadePercent',     4, '4 * level')

config.addComment()
config.addComment('********************')
config.addComment('Weapon Training')
config.addComment('  Do extra damage')
config.addComment('********************')
config.addComment()
weaponMaxLevel      = config.addVar('weaponMaxLevel',     10, 'Max level')
weaponLevelInterval = config.addVar('weaponLevelInterval', 3, 'Level interval')
weaponDamage        = config.addVar('weaponDamage',        6, 'Extra damage') 

config.addComment()
config.addComment('********************')
config.addComment('Hard Shell')
config.addComment('  Gain more armor')
config.addComment('********************')
config.addComment()
shellMaxLevel      = config.addVar('shellMaxLevel',     10, 'Max level')
shellLevelInterval = config.addVar('shellLevelInterval', 2, 'Level interval')
shellArmor         = config.addVar('shellArmor',       100, '100 armor per level')

config.addComment()
config.addComment('********************')
config.addComment('Rage')
config.addComment('  +Ultimate to get a speed boost') 
config.addComment('********************')
config.addComment()
rageMaxLevel      = config.addVar('rageMaxLevel',      5, 'Max level')
rageMinLevel      = config.addVar('rageMinLevel',     30, 'Min level')
rageLevelInterval = config.addVar('rageLevelInterval', 5, 'Level interval')
rageCoolDown      = config.addVar('rageCoolDown',     30, 'Cool down time')
rageSpeed         = config.addVar('rageSpeed',         8, 'Speed Boost')
rageTime          = config.addVar('rageTime',          5, 'Time in rage')

config.load(True)
########################################
wcs.Race(name).registerSkill("Turtle Training", int(trainingMaxLevel), int(trainingLevelInterval), "You gain more health, speed and higher jump as well as a chance to evade attacks.")
wcs.Race(name).registerSkill("Weapon Training", int(weaponMaxLevel), int(weaponLevelInterval), "You learn to master your weapon.")
wcs.Race(name).registerSkill("Hard Shell", int(trainingMaxLevel), int(trainingLevelInterval), "Your hard shell will protect you from most attacks.")
wcs.Race(name).registerUltimate("Rage", int(rageMinLevel), int(rageMaxLevel), int(rageLevelInterval), "Your a feirce fighter with a bad temper so you do more damage. <+Ultimate>") 
########################################

def player_spawn(ev):
    userid = ev['userid']
    player = wcs.Command(userid)
    
    if wcs.GetRace(userid) == name:
        playerlib.getPlayer(userid).set('model', 'models/player/techknow/tmnt/raphael.mdl')
        
        es.server.cmd('est_RemoveWeapon %s %s'%(userid, 1))
        es.server.cmd('est_RemoveWeapon %s %s'%(userid, 2))	

    turtleTrainingLevel = wcs.GetLevel(userid, name, 'Turtle Training')
    if turtleTrainingLevel:

        speed  = turtleTrainingLevel * int(trainingSpeed) * .01
        health = turtleTrainingLevel * int(trainingHealth)
        jump   = 1 - turtleTrainingLevel * int(trainingJump) * .01
        
        player.SpeedAdd(speed)
        player.HealthAdd(health)
            
        es.tell(userid, '#multi', text('training', {'speed': speed * 100, 'jump': jump * 100, 'health': health}, playerlib.getPlayer(userid).get("lang") ) )
            
        armorLevel = wcs.GetLevel(userid, name, 'Hard Shell')
        if armorLevel:
            armor = armorLevel * int(shellArmor)
            
            player.Armor(armor)
            
            es.tell(userid, '#multi', text('shell', {'armor': armor}, playerlib.getPlayer(userid).get("lang") ) )
            
def player_jump(ev):
    userid = ev['userid']
    player = wcs.Command(userid)
    turtleTrainingLevel = wcs.GetLevel(userid, name, 'Turtle Training')
    if turtleTrainingLevel:
        jump   = 1 - turtleTrainingLevel * int(trainingJump) * .01
        player.SetGravity(jump)
            
def item_pickup(ev):
    userid = ev['userid']
    
    if wcs.GetRace(userid) == name:
        es.server.cmd('est_RemoveWeapon %s %s'%(userid, 1))
        es.server.cmd('est_RemoveWeapon %s %s'%(userid, 2))

def player_hurt(ev):
    userid   = ev['userid']
    attacker = ev['attacker']
    damage   = int(ev['dmg_health'])
    victim   = wcs.Command(userid)
    
    weaponLevel = wcs.GetLevel(attacker, name, 'Weapon Training') * (int(weaponDamage) * .01)
    if ev['weapon'] == "knife" and weaponLevel:
        victim.Damage(damage * weaponLevel, 32, attacker)
        es.tell(attacker, '#multi', text('weapon attacker', {'damage' : damage * weaponLevel, 'player': es.getplayername(userid)}, playerlib.getPlayer(attacker).get("lang") ) )
        es.tell(userid, '#multi', text('weapon victim', {'damage' : damage * weaponLevel, 'player': es.getplayername(attacker)}, playerlib.getPlayer(attacker).get("lang") ) )

def prep_hurt(ev):
    userid   = ev['userid']
    attacker = ev['attacker']
    damage   = int(ev['dmg_health'])
    victim   = wcs.Command(userid)
    
    if attacker:
        evadeLevel = wcs.GetLevel(userid, name, 'Turtle Training') * int(trainEvadePercent)
        if evadeLevel:
            if evadeLevel >= random.randint(1,100):
                victim.SaveLife(damage)
                es.tell(userid, '#multi', text('evade', {'damage' : damage}, playerlib.getPlayer(userid).get("lang") ) )

def player_ultimate_on(ev):
    userid = ev['userid']
    player = wcs.Command(userid)
    
    rageLevel = wcs.GetLevel(userid, name, 'Rage')
    speed     = rageLevel * int(rageSpeed) *.01
    coolDown  = 190 - rageLevel * int(rageCoolDown)
    time      = rageLevel * int(rageTime)
    if rageLevel:
        player.SpeedAdd(speed)
        es.tell(userid, '#multi', text('rage on', {'speed' : speed * 100}, playerlib.getPlayer(userid).get("lang") ) )
        gamethread.delayedname(time, '%s_Rage' %userid, RageOff, userid)
        wcs.Command(userid).SetCoolDown('Rage', coolDown)
        
def RageOff(userid):
    player = wcs.Command(userid)
    
    rageLevel = wcs.GetLevel(userid, name, 'Rage')
    speed     = rageLevel * int(rageSpeed) *.01
    if rageLevel:
        player.SpeedAdd(-speed)
        es.tell(userid, '#multi', text('rage off', {'speed' : speed * 100}, playerlib.getPlayer(userid).get("lang") ) )
        gamethread.cancelDelayed('%s_Rage' %userid)
    
    
    